MagnetoDB
=========
**MagnetoDB** - key-value store for OpenStack

Links
------------------
Wiki - https://wiki.openstack.org/wiki/MagnetoDB

IRC - #magnetodb at FreeNode

Source code - https://github.com/stackforge/magnetodb

Documentation - http://magnetodb.readthedocs.org/en/latest/

Specs - http://magnetodb-specs.readthedocs.org/en/latest/
